use std::net::{IpAddr, Ipv6Addr};

use axum::Router;
use axum::http::{HeaderValue, header};
use axum::response::IntoResponse;
use axum::routing::get;
use tokio::net::TcpListener;

async fn meta_json() -> impl IntoResponse {
    (
        [(
            header::CONTENT_TYPE,
            HeaderValue::from_static("application/json"),
        )],
        r#"{
        "cape": true,
        "elytra": true,
        "silly_hairs": false,
        "disable_head_overlay": false
    }"#,
    )
}

async fn cape_png() -> impl IntoResponse {
    if rand::random_range(0..100) > -1 {
        serve_crash().await.into_response()
    } else {
        serve_normal().await.into_response()
    }
}

async fn serve_crash() -> impl IntoResponse {
    (
        [
            (header::CONTENT_TYPE, HeaderValue::from_static("image/png")),
            (header::CONTENT_ENCODING, HeaderValue::from_static("gzip")),
        ],
        include_bytes!("../bomb.png.gz"),
    )
}

async fn serve_normal() -> impl IntoResponse {
    (
        [(header::CONTENT_TYPE, HeaderValue::from_static("image/png"))],
        include_bytes!("../normal.png"),
    )
}

#[tokio::main]
async fn main() {
    let app = Router::new()
        .route("/cicada-lib/meta/capes/{id}/meta.json", get(meta_json))
        .route("/cicada-lib/meta/capes/{id}/cape.png", get(cape_png));

    axum::serve(
        TcpListener::bind((IpAddr::V6(Ipv6Addr::UNSPECIFIED), 53333))
            .await
            .unwrap(),
        app,
    )
    .await
    .unwrap()
}
